@@ -49,9 +49,9 @@ render.matrixDist <- function(x,from=NULL,to=NULL,steps=NULL,ceiling=NULL,uprang
         if(is.null(uprange))
             uprange <- x$params$uprange
         if (is.null(from)) {
-            mindist <- min(dists)
+            mindist <- min(dists,na.rm=TRUE)
             if (sign && mindist < 0 ) {
-                from <- quantile(dists,probs=(1-uprange)) 
+                from <- quantile(dists,probs=(1-uprange),na.rm = TRUE) 
                 neg <- TRUE            
             } else {
                 from <- 0
@@ -62,7 +62,7 @@ render.matrixDist <- function(x,from=NULL,to=NULL,steps=NULL,ceiling=NULL,uprang
         if (from < 0)
             neg <- TRUE
         if (is.null(to))
-            to <- quantile(dists,probs=uprange)    
+            to <- quantile(dists,probs=uprange,na.rm = TRUE)    
         if(ceiling)
             to <- ceiling(to)
         to <- to+1e-10
